# HMtai / HMFull
### P.S. This is ported version of [npm version](https://www.npmjs.com/package/hmtai) of package.
### [About v3.2.2](https://docs.l0calserve4.ml/hmtai-port-api/hmtai-api-changelogs#v3.2.2-01.12.2022)
------------
hmtai is an Anime / Hentai (NSFW) Image API which simplifies how you fetch random images from the local libraries! More features and functions will be added soon!
Will be i updating this API? Of course nyse, dude, but this API has a 18.000 NSFW picture, and 442 SFW picture. 18 442 total. All picture we added manually. 

My goal is to create the most depraved library ever and I think I got it.

Original package by [Mikun Hatsune](https://discord.bio/p/hatsunemikun) from [HMCommunity](https://discord.gg/apcn33CGqw)  
Ported by [NickSaltFoxu](https://discords.com/bio/p/oldnicksalty) 


## Installation
------------------------
```
pip install hmtai
```  

Structures
------------

```
   # Base function
   hmtai.get("source","category")

   # What libraries always return
   hmtai.get("hmtai", "neko") return "link"
   hmtai.get("hmtai", "manga") return "link"
```

------------
Examples
------------

```

   # HMtai
   import hmtai

   # Get pictures from hmtai library
   hmtai.get("hmtai","neko")

   # Get from others Libraries 
   hmtai.get("nekos","neko")
   hmtai.get("nekobot","neko")
```

## Changelog
------------
[Here](https://docs.l0calserve4.ml/hmtai-port-api/hmtai-api-changelogs#v3.2.2-01.12.2022)


## Support
------------
Original Package -> [HMCommunity Discord Server](https://discord.gg/apcn33CGqw) || This package -> NickSaltFox#7273 (or [issues](https://github.com/BlueBerrySans365/HMtai-PY/issues))

## List of Libraries
HMtai
---------------------

**SFW Categories**

| Function        | Description                        |
| --------------- | ---------------------------------- |
| wave            | Greeting! Wave gifs! (●'◡'●)      |
| tea             | I want some tea! ☕               |
| punch           | ONE PUUUUUUUUUUUNCH                |
| poke            | Poke-poke :P                       |
| pat             | Let's pat some good guys (*/ω＼*)  |
| kiss            | Kissu! :3                          |
| feed            | Who want eat?  :P                  |
| hug             | I like hugs, do you?               |
| cuddle          | Cuddle cuddle cuddle xD            |
| cry             | Bite bite biting :3                |
| slap            | BAKA!!                             |
| lick            | Mmm hum hum, so tasty~             |
| bite            | Nyaaaaaa!!                         |
| dance           | Move like lady jagger ヾ(≧▽≦*)o  |
| boop            | Boopyy                             |
| sleep           | Zzz 💤                            |
| like            | I like it, nice 👍                |
| kill            | Kill everyone, everybody!          |
| nosebleed       | That's...impressive                |
| threaten        | Rrrr                               |
| tickle          | Tiiickle tickle tickle :3          |
| depression      | SFW depression Gifs :c             |
| jahy_arts       | So hot Jahy :3                     |
| neko_arts       | SFW Neko Girls (Cat Girls)         |
| coffee_arts     | Do you want some coffee? And girls :3|
| wallpaper       | SFW Wallpaper with Anime           |
| mobileWallpaper | SFW Wallpaper with Anime on Mobile |

**NSFW Categories**

| Function            | Description                                                        |
| ------------------- | ------------------------------------------------------------------ |
| anal                | Does somebody like being in all holes?~                            |
| ass                 | I know you like anime ass~ uwu                                     |
| bdsm                | If you don't know what it is, search it up                         |
| cum                 | Basically sticky white stuff that is usually milked from sharpies. |
| classic             | Relaxing classic kekus uwu                                         |
| creampie            | So hot, sticky, and inside uwu                                     |
| manga               | Sends a random doujin page imageURL!                               |
| femdom              | Female Domination?                                                 |
| hentai              | Sends a random vanilla hentai imageURL~                            |
| incest              | I know, you like it. Brothet and sister <3 And..mo...omg           |
| masturbation        | You like lewd solo?~                                               |
| public              | Some people like do it on a public..uh~                             |
| ero                 | eros, ero Uniforms, etc, you know what eros are :3                 |
| orgy                | Group Lewd Acts                                                    |
| elves               | So, it's not Elvis Presley, but i know, you like it :)             |
| yuri                | What about cute Les?~                                              |
| pantsu              | I mean... just why? You like underwear?                            |
| glasses             | Girls that wear glasses, uwu~                                      |
| cuckold             | Wow, I won't even question your fetishes.                          |
| blowjob             | Basically an image of a girl sucking on a sharp blade!             |
| boobjob             | So soft, round ... gentle ... damn we love it                      |
| footjob             | So you like smelly feet huh?                                       |
| handjob             | So you like how's it feeling in hand, huh?                         |
| boobs               | A-am..that's normal size!                                          |
| thighs              | Oh, i so like it, it's best of the best, like a religion <3        |
| pussy               | The genitals of a female, or a cat, you give the meaning.          |
| ahegao              | So happy woman faces :))                                           |
| uniform             | School and many other Uniforms~                                    |
| gangbang            | 5 on 1? Uh..                                                       |
| tentacles           | I'm sorry but, why do you like it? Uh..                            |
| gif                 | Basically an animated image, so yes :3                             |
| nsfwNeko            | NSFW Neko Girls (Cat Girls)                                        |
| nsfwMobileWallpaper | NSFW Anime Mobile Wallpaper                                        |
| zettaiRyouiki       | That one part of the flesh being squeeze in thigh-highs~<3         |

Nekos
------------

-  ball8 Function \| Magic 8ball give you answer 

**SFW Function(s)**

Function|Description
--------|-----------------------------------
pat     |Let's pet everyone gifs :3
hug     |Let's hug everyone gifs <3
kiss    |let's kiss and make up ;3
cry     |So sad T.T
slap    |Wanna somebody slap? SLAP SLAP! >:<
smug    |Will show you a malicious face! >:3
neko    |What about sweet neko?~
waifu   |Generate Waifu with AI
cuddle  |Cuuuddle cuddle cuddle~
feed    |You wanna eat? I gonna feed you :3
foxgirl |Is this a parody of Neko?


**NSFW Function(s)**

Function|Description
--------|-----------------------------------
nekogif |This is what are you wanted?...

NekoBot
------------

**SFW Function(s)**

Function  |Description
----------|-----------------------------------
kanna     |Sweet Kanna images ｶﾜ(・∀・)ｲｲ!!
neko      |All your love in one picture !(´ \* ω \* \`)!
holo      |What you think about kitsune Holo? >:3
kemonomimi|IDK what it that, but, it's something sweet ╯-╰
coffee    |What are you up to little mischievous? (0ˍ0)
gah       |Are you sure you want to punch? Maybe not worth it? >:<


**NSFW Function(s)**


Function  |Description
----------|-----------------------------------
hentai    |Mmmmm, anata wa hentai desu!!
hass      |Has...Has what? Idk, maybe you know, huh :P
boobs     |Very big, and so..soft, yeah, soft..very..very..soft :>
paizuri   |You like something like yet? It some..nice
yuri      |Two beautiful girls, it's awesome <3
thigh     |It's my fetish, it's my weakness, dude, it's a perfect
lewdneko  |Lewd Neko? GIVE ME ALL THAT YOU HAVE!!! Copypast, yeah..
midriff   |Midriff, it's..Maybe, but i not fun of this..Maybe you?
kitsune   |Kitsune. Just a..Fox-Girl, you love neko? Maybe fox too?
tentacle  |Ugh....I don't like this, it's dirty and disgusting
anal      |It's not bad, but, if we look on detail...No, please, no
hanal     |It's not bad too, but..wait, is it same?! Or...not?
hneko     |Are you sure about that? YES, WE'RE SURE!
wallpaper |Do you like some...good wallpaper for Desktop?~


Neko-Love
------------

**SFW Function(s)**

Function |Description
----------|-----------------------------------
pat      |For those with soft hands UωU
hug      |All your love in one picture !(´ \* ω \* \`)!
kiss     |Leave your memories in one action >:3
cry      |Sometimes you just need to cry a little ╯-╰
slap     |Are you sure you want to slap? Maybe not worth it? o_o
smug     |What are you up to little mischievous? (0ˍ0)
punch    |Are you sure you want to punch? Maybe not worth it? >:<
neko     |Just Neko-chans to order (●'^'●)
kitsune  |Kitsune... IT IS GREAT (¬.¬)
waifu    |Yours and only yours (probably) waifu


**NSFW Function(s)**


Function |Description
----------|-----------------------------------
nekolewd |Neko? Lewd Neko? GIVE ME ALL THAT YOU HAVE!!!
